# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/danmaku.proto
"""Generated protocol buffer code."""
from __future__ import annotations

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16protobuf/danmaku.proto"\xba\x01\n\x0b\x44\x61nmakuElem\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12\x0c\n\x04mode\x18\x03 \x01(\x05\x12\x10\n\x08\x66ontsize\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\r\x12\x10\n\x08mid_hash\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\r\n\x05\x63time\x18\x08 \x01(\x03\x12\x0e\n\x06\x61\x63tion\x18\t \x01(\t\x12\x0c\n\x04pool\x18\n \x01(\x05\x12\x0e\n\x06id_str\x18\x0b \x01(\t"+\n\x0c\x44\x61nmakuEvent\x12\x1b\n\x05\x65lems\x18\x01 \x03(\x0b\x32\x0c.DanmakuElemb\x06proto3'
)


_DANMAKUELEM = DESCRIPTOR.message_types_by_name["DanmakuElem"]
_DANMAKUEVENT = DESCRIPTOR.message_types_by_name["DanmakuEvent"]
DanmakuElem = _reflection.GeneratedProtocolMessageType(
    "DanmakuElem",
    (_message.Message,),
    {
        "DESCRIPTOR": _DANMAKUELEM,
        "__module__": "protobuf.danmaku_pb2"
        # @@protoc_insertion_point(class_scope:DanmakuElem)
    },
)
_sym_db.RegisterMessage(DanmakuElem)

DanmakuEvent = _reflection.GeneratedProtocolMessageType(
    "DanmakuEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _DANMAKUEVENT,
        "__module__": "protobuf.danmaku_pb2"
        # @@protoc_insertion_point(class_scope:DanmakuEvent)
    },
)
_sym_db.RegisterMessage(DanmakuEvent)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _DANMAKUELEM._serialized_start = 27
    _DANMAKUELEM._serialized_end = 213
    _DANMAKUEVENT._serialized_start = 215
    _DANMAKUEVENT._serialized_end = 258
# @@protoc_insertion_point(module_scope)
